import { getModelForClass, index, modelOptions, mongoose, prop, ReturnModelType, Severity } from '@typegoose/typegoose'
import { dbconn } from 'decorators/dbconn'
import { BaseModule } from './Base'

/**
 * google 和 apple in-app-purchase 的原始记录
 * 不作处理, 只记录, 所以会有很多重复的记录
 */
@dbconn('pay')
@index({ orderId: 1 }, { unique: false })
@index({ account: 1 }, { unique: false })
@modelOptions({
  schemaOptions: { collection: 'inapp_origin_record', timestamps: true },
  options: { allowMixed: Severity.ALLOW },
})
export class InAppRecordClass extends BaseModule {
  // 用户账号
  @prop()
  public account: string
  @prop()
  public channel: string
  // 渠道返回的原始资料
  @prop({ type: mongoose.Schema.Types.Mixed })
  public data: any

  public static async addRecord(account: string, data: any, channel: string) {
    let record = new InAppRecord({
      account,
      data,
      channel,
    })
    return record.save()
  }
}

export const InAppRecord = getModelForClass(InAppRecordClass, { existingConnection: InAppRecordClass.db })
