import logger from 'logger/logger'
import { ReportQueue } from 'modules/ReportQueue'
import * as schedule from 'node-schedule'
import { reportApplePurchaseResult, reportGooglePurchaseResult } from 'service/game.svr'
import { singleton } from 'zutils'

/**
 * 定时查询加密货币购买和内购上报失败的记录, 并重试
 * 
 *    *    *    *    *    *
 ┬    ┬    ┬    ┬    ┬    ┬
 │    │    │    │    │    │
 │    │    │    │    │    └ day of week (0 - 7) (0 or 7 is Sun)
 │    │    │    │    └───── month (1 - 12)
 │    │    │    └────────── day of month (1 - 31)
 │    │    └─────────────── hour (0 - 23)
 │    └──────────────────── minute (0 - 59)
 └───────────────────────── second (0 - 59, OPTIONAL)
 */
@singleton
export default class PayReportSchedule {
  async parseAllRecord() {
    try {
      let records = await ReportQueue.findUnfinishedRecords()
      for (let record of records) {
        logger.info(`parse record: ${record.id}, channel: ${record.channel}`)
        switch (record.channel) {
          case 'google':
            await reportGooglePurchaseResult([record.toInAppData()])
            break
          case 'apple':
            await reportApplePurchaseResult([record.toInAppData()])
            break
          case 'alchemy':
            break
          default:
            break
        }
      }
    } catch (err) {
      logger.info('error query unfinished report records', err.message || err)
    }
  }
  scheduleAll() {
    const job = schedule.scheduleJob('1 * * * *', async () => {
      await this.parseAllRecord()
    })
    this.parseAllRecord()
  }
}
