import axios from 'axios'
import { HTTP_GET, HTTP_POST } from 'common/Constants'
import logger from 'logger/logger'
import { generateKVStr } from 'zutils/utils/net.util'
import { prepareOkxReqCfg } from 'utils/okx.utils'

const OKX_BASE = 'https://www.okx.com/api/v5/mktplace'

/**
 * https://www.okx.com/web3/build/docs/build-dapp/marketplace-create-a-listing
 */
export function beginSell(data: any) {
  if (typeof data === 'object') {
    data = JSON.stringify(data)
  }
  let config = {
    method: HTTP_POST,
    url: `${OKX_BASE}/nft/markets/create-listing`,
    data,
  }
  config = prepareOkxReqCfg(config)
  return axios.request(config)
}

export function submitOrder(data: any) {
  if (typeof data === 'object') {
    data = JSON.stringify(data)
  }
  let config = {
    method: HTTP_POST,
    url: `${OKX_BASE}/nft/markets/submit-listing`,
    data,
  }
  config = prepareOkxReqCfg(config)
  return axios.request(config)
}
/**
 * https://www.okx.com/web3/build/docs/build-dapp/marketplace-buy-orders
 */
export function buyOrder(data: any) {
  if (typeof data === 'object') {
    data = JSON.stringify(data)
  }
  let config = {
    method: HTTP_POST,
    url: `${OKX_BASE}/nft/markets/buy`,
    data,
  }
  config = prepareOkxReqCfg(config)
  return axios.request(config)
}

/**
 * https://www.okx.com/web3/build/docs/build-dapp/marketplace-query-listing
 */
export function listings(data: any) {
  let url = `${OKX_BASE}/nft/markets/listings`
  if (data) {
    url = generateKVStr({ data, uri: url })
  }
  let config = {
    method: HTTP_GET,
    url,
  }
  config = prepareOkxReqCfg(config)
  return axios.request(config)
}
/**
 * https://www.okx.com/web3/build/docs/build-dapp/marketplace-query-offer
 */
export function offers(data: any) {
  let url = `${OKX_BASE}/nft/markets/offers`
  if (data) {
    url = generateKVStr({ data, uri: url })
  }
  let config = {
    method: HTTP_GET,
    url,
  }
  config = prepareOkxReqCfg(config)
  return axios.request(config)
}
