
import { ReadOnlyCache } from 'common/ReadOnlyCache'
import { createSigner, createVerifier } from 'fast-jwt'

import buildGetJwks from 'get-jwks'

const domain = 'https://auth.immutable.com'

const privateKey = `-----BEGIN PRIVATE KEY-----
${process.env.REFRESH_TOKEN_SECRET_PRIVATE}
-----END PRIVATE KEY-----
`
const publicKey = `-----BEGIN PUBLIC KEY-----
${process.env.REFRESH_TOKEN_SECRET_PUBLIC}
-----END PUBLIC KEY-----
`
const REFRESH_TOKEN_EXPIRES_IN = 30 * 24 * 60 * 60 * 1000
const privateKeyWallet = `-----BEGIN PRIVATE KEY-----
${process.env.API_TOKEN_SECRET_PRIVATE}
-----END PRIVATE KEY-----
`
const publicKeyWallet = `-----BEGIN PUBLIC KEY-----
${process.env.API_TOKEN_SECRET_PUBLIC}
-----END PUBLIC KEY-----
`
const WALLET_TOKEN_EXPIRES_IN = 30 * 24 * 60 * 60 * 1000

const getJwks = buildGetJwks({ })

export const generateRefreshToken = (data: any) => {
  const signSync = createSigner({
    algorithm: 'EdDSA',
    expiresIn: REFRESH_TOKEN_EXPIRES_IN,
    key: privateKey,
  })
  return signSync(data)
}

export const verifyRefreshToken = (token: string) => {
  const verifier = createVerifier({
    algorithms: ['EdDSA'],
    key: publicKey,
  })
  return verifier(token)
}

export const generateWalletToken = (data: any) => {
  const signSync = createSigner({
    algorithm: 'EdDSA',
    expiresIn: WALLET_TOKEN_EXPIRES_IN,
    key: privateKeyWallet,
  })
  return signSync(data)
}

export const verifyWalletToken = (token: string) => {
  const verifier = createVerifier({
    algorithms: ['EdDSA'],
    key: publicKeyWallet,
  })
  return verifier(token)
}

export const verifyPassportToken = (token: string) => {
  const verifyWithPromise = createVerifier({
    key: async function (header) {
      let publicKey = new ReadOnlyCache().getData('passport_public_key')
      if (!publicKey) {
        publicKey = await getJwks.getPublicKey({
          kid: header.kid,
          alg: header.alg,
          domain,
        })
        new ReadOnlyCache().setData('passport_public_key', publicKey)
      }
      return Promise.resolve(publicKey)
    },
  })
  return verifyWithPromise(token)
}

export const verifyCombinedToken = (token: string) => {
  let tokenSuffix = token.split('.')[3]
  tokenSuffix = tokenSuffix || 'passport'
  token = token.replace(`.${tokenSuffix}`, '')
  if (tokenSuffix === 'passport') {
    return verifyPassportToken(token)
  } else {
    return verifyWalletToken(token)
  }
}